@@ -53,10 +53,20 @@ async def _cmd_handler(args, unknown, error):
         )
     elif args.action == 'benchmark':
         await repository.benchmark(args.name, settings=settings)
-    elif args.action == 'upload':
-        await repository.upload(
+    elif args.action == 'upload-objects':
+        await repository.upload_objects(
             args.path, rate_limit=args.rate_limit, skip_existing=args.skip_existing
         )
+    elif args.action == 'download-objects':
+        await repository.download_objects(
+            path=args.path,
+            object_regex=args.objects_regex,
+            skip_existing=args.skip_existing,
+        )
+    elif args.action == 'list-objects':
+        await repository.list_objects(object_regex=args.objects_regex)
+    elif args.action == 'delete-objects':
+        await repository.delete_objects(args.object, confirm=not args.yes)
     elif args.action == 'add-key':
         if args.shared:
             await repository.unlock(password=args.password, key=args.key)
@@ -80,7 +90,7 @@ async def _cmd_handler(args, unknown, error):
                 path=args.path,
             )
         elif args.action == 'delete':
-            await repository.delete_snapshots(args.snapshot)
+            await repository.delete_snapshots(args.snapshot, confirm=not args.yes)
         elif args.action == 'clean':
             await repository.clean()
         elif args.action in {'lf', 'list-files'}:
